"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RabbitMqConsumerMonitoringInterceptor = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const nestjs_rabbitmq_1 = require("@golevelup/nestjs-rabbitmq");
const sdk_nestjs_monitoring_1 = require("@multiversx/sdk-nestjs-monitoring");
let RabbitMqConsumerMonitoringInterceptor = class RabbitMqConsumerMonitoringInterceptor {
    constructor(metricsService) {
        this.metricsService = metricsService;
    }
    intercept(context, next) {
        const isRmqContext = (0, nestjs_rabbitmq_1.isRabbitContext)(context);
        if (!isRmqContext) {
            return next.handle();
        }
        const consumer = context.getClass().name;
        const profiler = new sdk_nestjs_monitoring_1.PerformanceProfiler();
        return next
            .handle()
            .pipe((0, operators_1.tap)(() => {
            this.metricsService.setConsumer(consumer, profiler.stop());
        }), (0, operators_1.catchError)(err => {
            this.metricsService.setConsumer(consumer, profiler.stop());
            return (0, rxjs_1.throwError)(() => err);
        }));
    }
};
RabbitMqConsumerMonitoringInterceptor = tslib_1.__decorate([
    (0, common_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [sdk_nestjs_monitoring_1.MetricsService])
], RabbitMqConsumerMonitoringInterceptor);
exports.RabbitMqConsumerMonitoringInterceptor = RabbitMqConsumerMonitoringInterceptor;
//# sourceMappingURL=rabbitmq-consumer-monitoring.interceptor.js.map