"use strict";
var RabbitPublisherService_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.RabbitPublisherService = void 0;
const tslib_1 = require("tslib");
const crypto_1 = tslib_1.__importDefault(require("crypto"));
const nestjs_rabbitmq_1 = require("@golevelup/nestjs-rabbitmq");
const common_1 = require("@nestjs/common");
const sdk_nestjs_common_1 = require("@multiversx/sdk-nestjs-common");
const sdk_nestjs_monitoring_1 = require("@multiversx/sdk-nestjs-monitoring");
const constants_1 = require("./entities/constants");
let RabbitPublisherService = RabbitPublisherService_1 = class RabbitPublisherService {
    constructor(amqpConnection, storageService, options) {
        this.amqpConnection = amqpConnection;
        this.storageService = storageService;
        this.options = options;
        this.logger = new sdk_nestjs_common_1.OriginLogger(RabbitPublisherService_1.name);
    }
    generateDuplicateMessageKey(exchange, input) {
        const inputStringify = typeof input === 'object' ? JSON.stringify(input) : input;
        const inputHex = crypto_1.default.createHash('sha256').update(inputStringify).digest('hex');
        return `duplicateCheck:${exchange}:${inputHex}`;
    }
    async isExchangeDisabled(exchange) {
        const key = `${exchange}:disabled`;
        if (this.storageService) {
            const isDisabled = await this.storageService.get(key);
            return isDisabled === 'true';
        }
        return false;
    }
    async checkForDuplicatedMessages(exchange, input, source) {
        var _a, _b;
        if (this.storageService && ((_a = this.options) === null || _a === void 0 ? void 0 : _a.checkForDuplicates)) {
            const key = this.generateDuplicateMessageKey(exchange, input);
            const existsInStorage = await this.storageService.get(key);
            if (existsInStorage) {
                sdk_nestjs_monitoring_1.MetricsService.setDuplicatedMessageDetected(exchange, source || '');
                if ((_b = this.options) === null || _b === void 0 ? void 0 : _b.logsVerbose) {
                    this.logger.warn('Duplicate message detected, not publishing to RabbitMq Exchange.', {
                        exchange,
                        input,
                    });
                }
            }
            else {
                const ttl = this.options.duplicatesCheckTtl || sdk_nestjs_common_1.Constants.oneMinute();
                const profiler = new sdk_nestjs_monitoring_1.PerformanceProfiler();
                await this.storageService.set(key, '1', 'EX', ttl);
                profiler.stop();
                sdk_nestjs_monitoring_1.MetricsService.setRedisCommonDuration('SET', profiler.duration);
            }
        }
    }
    async invalidateDuplicateMessageKey(exchange, input) {
        const key = this.generateDuplicateMessageKey(exchange, input);
        if (this.storageService) {
            await this.storageService.delete(key);
        }
    }
    async publish(exchange, input, source) {
        var _a, _b;
        try {
            const isDisabled = await this.isExchangeDisabled(exchange);
            if (isDisabled) {
                if ((_a = this.options) === null || _a === void 0 ? void 0 : _a.logsVerbose) {
                    this.logger.log(`Publishing to RabbitMq Exchange: ${exchange} is disabled`);
                }
                return;
            }
            await this.checkForDuplicatedMessages(exchange, input, source);
            if ((_b = this.options) === null || _b === void 0 ? void 0 : _b.logsVerbose) {
                this.logger.log(`Publishing to RabbitMq Exchange: ${exchange}`, { input });
            }
            sdk_nestjs_monitoring_1.MetricsService.setQueuePublish(exchange, source || '');
            await this.amqpConnection.publish(exchange, '', input);
        }
        catch (err) {
            this.logger.error('An error occurred while publishing to RabbitMq Exchange.', {
                exchange,
                input,
                error: err,
            });
        }
    }
};
RabbitPublisherService = RabbitPublisherService_1 = tslib_1.__decorate([
    (0, common_1.Injectable)(),
    tslib_1.__param(1, (0, common_1.Optional)()),
    tslib_1.__param(2, (0, common_1.Optional)()),
    tslib_1.__param(2, (0, common_1.Inject)(constants_1.RABBIT_ADDITIONAL_OPTIONS)),
    tslib_1.__metadata("design:paramtypes", [nestjs_rabbitmq_1.AmqpConnection,
        sdk_nestjs_common_1.SwappableSettingsService, Object])
], RabbitPublisherService);
exports.RabbitPublisherService = RabbitPublisherService;
//# sourceMappingURL=publisher.service.js.map