"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PublicRabbitConsumer = exports.CompetingRabbitConsumer = void 0;
const tslib_1 = require("tslib");
const nestjs_rabbitmq_1 = require("@golevelup/nestjs-rabbitmq");
const common_1 = require("@nestjs/common");
const uuid = tslib_1.__importStar(require("uuid"));
const sdk_nestjs_monitoring_1 = require("@multiversx/sdk-nestjs-monitoring");
function QueueMetricsConsumer(queue) {
    return (_target, key, descriptor) => {
        const childMethod = descriptor.value;
        descriptor.value = async function (...args) {
            sdk_nestjs_monitoring_1.MetricsService.setQueueConsume(queue, key);
            const cpuProfiler = new sdk_nestjs_monitoring_1.CpuProfiler();
            const performanceProfiler = new sdk_nestjs_monitoring_1.PerformanceProfiler();
            const data = await childMethod.apply(this, args);
            performanceProfiler.stop();
            sdk_nestjs_monitoring_1.MetricsService.setQueueHandlerCpu(queue, key, cpuProfiler.stop());
            sdk_nestjs_monitoring_1.MetricsService.setQueueHandlerDuration(queue, key, performanceProfiler.duration);
            return data;
        };
        return descriptor;
    };
}
const CompetingRabbitConsumer = (config) => {
    const { queue, exchange, disable } = config;
    if (disable) {
        return (0, common_1.applyDecorators)();
    }
    return (0, common_1.applyDecorators)(QueueMetricsConsumer(queue), (0, nestjs_rabbitmq_1.RabbitSubscribe)({
        queue,
        exchange,
        routingKey: '',
    }));
};
exports.CompetingRabbitConsumer = CompetingRabbitConsumer;
const PublicRabbitConsumer = (config) => {
    const { queue, exchange, disable } = config;
    if (disable) {
        return (0, common_1.applyDecorators)();
    }
    return (0, common_1.applyDecorators)(QueueMetricsConsumer(`${queue}_${uuid.v4()}`), (0, nestjs_rabbitmq_1.RabbitSubscribe)({
        queue: `${queue}_${uuid.v4()}`,
        exchange,
        routingKey: '',
        queueOptions: {
            autoDelete: true,
        },
    }));
};
exports.PublicRabbitConsumer = PublicRabbitConsumer;
//# sourceMappingURL=subscribers.decorators.js.map